==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/types/NtoNParent.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
namespace com.db4o.test.types {

   public class NtoNParent: RTest {
      
      public NtoNParent() : base() {
      }
      public NtoNChild[] children;
      
      public override void set(int ver) {
         children = new NtoNChild[3];
         for (int i = 0; i < 3; i++) {
            children[i] = new NtoNChild();
            children[i].parents = new NtoNParent[2];
            children[i].parents[0] = this;
            children[i].parents[1] = new NtoNParent();
            children[i].parents[1].children = new NtoNChild[1];
            children[i].parents[1].children[0] = children[i];
            children[i].name = "ver" + ver + "child" + i;
         }
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/types/NtoNParent.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
namespace com.db4o.test.types {

   public class NtoNParent: RTest {
      
      public NtoNParent() : base() {
      }
      public NtoNChild[] children;
      
      public override void Set(int ver) {
         children = new NtoNChild[3];
         for (int i = 0; i < 3; i++) {
            children[i] = new NtoNChild();
            children[i].parents = new NtoNParent[2];
            children[i].parents[0] = this;
            children[i].parents[1] = new NtoNParent();
            children[i].parents[1].children = new NtoNChild[1];
            children[i].parents[1].children[0] = children[i];
            children[i].name = "ver" + ver + "child" + i;
         }
      }
   }
}
